@@ -439,9 +439,16 @@ public class JavaBridge {
 	}
 
 	public static boolean dispatchDeviceEvent (DeviceEvent de) {
-		if (de == null) return false;
-		else return AccessUtil.getRegistryObject().
-			getDeviceEventController().notifyListenersSync(de);
+		try {
+			if (de == null) return false;
+			else return AccessUtil.getRegistryObject().
+				getDeviceEventController().notifyListenersSync(de);
+		}
+		catch (Exception e)
+		{
+			System.out.println("Exception in dispatchDeviceEvent " + e);
+			return false;
+		}
 	}
 
 	public static void dispatchFocusEvent(java.lang.Object eventSource) {
@@ -1061,8 +1068,8 @@ public class JavaBridge {
 		    return true;
 			
 		} catch (Exception e) {
-		    e.printStackTrace();
-		    return false;
+                    System.out.println("Error registering application, exception is: "+ e);
+                    return false;
 		}
 	}
 	
